@@ -14,8 +14,12 @@ from gremlinapi.exceptions import (
 )
 
 from gremlinapi.gremlinapi import GremlinAPI
-from gremlinapi.http_clients import get_gremlin_httpclient
+from gremlinapi.http_clients import (
+    get_gremlin_httpclient,
+    GremlinAPIHttpClient,
+)
 
+from typing import Union, Type
 
 log = logging.getLogger("GremlinAPI.client")
 
@@ -23,9 +27,14 @@ log = logging.getLogger("GremlinAPI.client")
 class GremlinAPIMetadata(GremlinAPI):
     @classmethod
     @register_cli_action("get_metadata", ("",), ("teamId",))
-    def get_metadata(cls, https_client=get_gremlin_httpclient(), *args, **kwargs):
-        method = "GET"
-        endpoint = cls._optional_team_endpoint("/metadata", **kwargs)
-        payload = cls._payload(**{"headers": https_client.header()})
+    def get_metadata(
+        cls,
+        https_client: Type[GremlinAPIHttpClient] = get_gremlin_httpclient(),
+        *args: tuple,
+        **kwargs: dict,
+    ) -> dict:
+        method: str = "GET"
+        endpoint: str = cls._optional_team_endpoint("/metadata", **kwargs)
+        payload: dict = cls._payload(**{"headers": https_client.header()})
         (resp, body) = https_client.api_call(method, endpoint, **payload)
         return body
