@@ -14,7 +14,12 @@ from gremlinapi.exceptions import (
 )
 
 from gremlinapi.gremlinapi import GremlinAPI
-from gremlinapi.http_clients import get_gremlin_httpclient
+from gremlinapi.http_clients import (
+    get_gremlin_httpclient,
+    GremlinAPIHttpClient,
+)
+
+from typing import Union, Type
 
 
 log = logging.getLogger("GremlinAPI.client")
@@ -23,18 +28,28 @@ log = logging.getLogger("GremlinAPI.client")
 class GremlinAPIProviders(GremlinAPI):
     @classmethod
     @register_cli_action("list_providers", ("",), ("",))
-    def list_providers(cls, https_client=get_gremlin_httpclient(), *args, **kwargs):
-        method = "GET"
-        endpoint = "/providers"
-        payload = cls._payload(**{"headers": https_client.header()})
+    def list_providers(
+        cls,
+        https_client: Type[GremlinAPIHttpClient] = get_gremlin_httpclient(),
+        *args: tuple,
+        **kwargs: dict,
+    ) -> dict:
+        method: str = "GET"
+        endpoint: str = "/providers"
+        payload: dict = cls._payload(**{"headers": https_client.header()})
         (resp, body) = https_client.api_call(method, endpoint, **payload)
         return body
 
     @classmethod
     @register_cli_action("list_aws_services", ("",), ("",))
-    def list_aws_services(cls, https_client=get_gremlin_httpclient(), *args, **kwargs):
-        method = "GET"
-        endpoint = "/providers/aws"
-        payload = cls._payload(**{"headers": https_client.header()})
+    def list_aws_services(
+        cls,
+        https_client: Type[GremlinAPIHttpClient] = get_gremlin_httpclient(),
+        *args: tuple,
+        **kwargs: dict,
+    ) -> dict:
+        method: str = "GET"
+        endpoint: str = "/providers/aws"
+        payload: dict = cls._payload(**{"headers": https_client.header()})
         (resp, body) = https_client.api_call(method, endpoint, **payload)
         return body
