@@ -149,12 +149,14 @@ class GremlinScenarioNode(object):
             error_msg: str = f"Node Name is required to build a scenario node, please set a node name"
             log.error(error_msg)
             raise GremlinParameterError(error_msg)
-        return f"{self.name}-{self.id}"
+        # return f"{self.name}-{self.id}"
+        return f"{self.id}"
 
     def api_model(self) -> dict:
         model = {
             "type": self.node_type,
             "guid": self.uuid,
+            "name": self.name,
             "id": self.index,
             "next": self.next,
         }
@@ -179,6 +181,8 @@ class GremlinScenarioGraphHelper(object):
         self._hypothesis: str = str()
         self._name: str = str()
         self._nodes: _GremlinNodeGraph = _GremlinNodeGraph()
+        self._continuous_nodes: list = list()
+        self.continuous_nodes: list = []
         self._start = str()
         self.description: str = kwargs.get("description", None)  # type: ignore
         self.hypothesis: str = kwargs.get("hypothesis", None)  # type: ignore
@@ -207,13 +211,18 @@ class GremlinScenarioGraphHelper(object):
             )
             log.error(error_msg)
             raise GremlinParameterError(error_msg)
-        if not self._nodes.head:
-            _default_edge = False
-        if _default_edge:
-            tail_node = self._nodes._nodes[-1]
-        self._nodes.append(node)
-        if _default_edge:
-            self.add_edge(node, tail_node)
+        # If the node is a Continuous Status Check, it does not get added to the node chain
+        if type(node) == GremlinScenarioContinuousStatusCheckNode:
+            log.debug("Found GremlinContinuousStatusCheckNode")
+            self.continuous_nodes.append(node)
+        else:
+            if not self._nodes.head:
+                _default_edge = False
+            if _default_edge:
+                tail_node = self._nodes._nodes[-1]
+            self._nodes.append(node)
+            if _default_edge:
+                self.add_edge(node, tail_node)
 
     def remove_node(self, node: GremlinScenarioNode) -> None:
         """
@@ -231,7 +240,10 @@ class GremlinScenarioGraphHelper(object):
         GremlinParameterError
             If the _node to remove is the current head node
         """
-        self._nodes.remove(node)
+        if type(node) == GremlinScenarioContinuousStatusCheckNode:
+            self._continuous_nodes.remove(node)
+        else:
+            self._nodes.remove(node)
 
     def get_last_node(self) -> GremlinScenarioNode:
         return self._nodes._nodes[-1]
@@ -260,12 +272,18 @@ class GremlinScenarioGraphHelper(object):
         Raises
         ------
         GremlinParameterError
-            If the _src_node or dst_node are not of the type GremlinScenarioNode
+            If the _src_node or dst_node are not of the type GremlinScenarioNode, or are of the type GremlinContinuousStatusCheckNode
         """
         if not issubclass(type(dst_node), GremlinScenarioNode):
             error_msg: str = f"add_edge expects GremlinScenarioNode (or None), received {type(dst_node)}"
             log.error(error_msg)
             raise GremlinParameterError(error_msg)
+        if (type(dst_node) == GremlinScenarioContinuousStatusCheckNode) or (
+            type(_src_node) == GremlinScenarioContinuousStatusCheckNode
+        ):
+            error_msg = f"add_edge cannot be used with {type(dst_node)}"
+            log.error(error_msg)
+            raise GremlinParameterError(error_msg)
         if not _src_node:
             _src_node = self.get_last_node()
         self._nodes.add_edge(_src_node, dst_node, _weight)
@@ -304,6 +322,35 @@ class GremlinScenarioGraphHelper(object):
         else:
             self._nodes.remove_edge(src_node, _edge_node)
 
+    def set_head_node(self, node: GremlinScenarioNode) -> None:
+        if not issubclass(type(node), GremlinScenarioNode):
+            error_msg: str = f"set_head_node expects GremlinScenarioNode (or None), received {type(node)}"
+            log.error(error_msg)
+            raise GremlinParameterError(error_msg)
+        self._nodes.head = node
+
+    def get_nodes_parallel(self) -> dict:
+        model = {
+            "concurrentNode": {
+                "id": "concurrentNode",
+                "type": "Concurrent",
+                "branches": [],
+            }
+        }
+        continuous_id = 0
+        for c_node in self.continuous_nodes:
+            if type(c_node) != GremlinScenarioContinuousStatusCheckNode:
+                raise GremlinParameterError(
+                    "Error, non-continuous node found in continuous context"
+                )
+            log.debug("Adding new continuous node to model")
+            new_node = c_node.api_model()
+            new_node["nodes"]["0"]["branchId"] = "concurrentNode-%d" % continuous_id
+            new_node["start_id"] = "0"
+            continuous_id += 1
+            model["concurrentNode"]["branches"].append(new_node)  # type: ignore
+        return model
+
     @property
     def description(self) -> str:
         return self._description
@@ -345,19 +392,34 @@ class GremlinScenarioGraphHelper(object):
         self._name = _name
 
     def api_model(self) -> dict:
+        log.debug("in api_model")
         model: dict = {
             "description": self.description,
             "hypothesis": self.hypothesis,
             "name": self.name,
         }
-        if self._nodes.head is not None:
+        if not self.continuous_nodes:
+            log.debug("no continuous nodes")
+            if self._nodes.head is not None:
+                model["graph"] = {
+                    "start_id": "0",
+                    "nodes": self._nodes.get_nodes_linear(),
+                }
+        elif self.continuous_nodes:
+            log.debug("yes continuous nodes")
+            log.debug(str(self._nodes == True))
             model["graph"] = {
-                "start_id": "0",
-                "nodes": self._nodes.get_nodes_linear()
-                # "nodes": {
-                #     node.uuid: data for node, data in self._nodes.nodes_data_linear()
-                # }
+                "start_id": "concurrentNode",
+                "nodes": self.get_nodes_parallel(),
             }
+            model["graph"]["nodes"]["concurrentNode"]["branches"].append(
+                {
+                    "nodes": self._nodes.get_nodes_linear(
+                        branch_id=len(self.continuous_nodes)
+                    ),
+                    "start_id": "0",
+                }
+            )
         return model
 
     def __repr__(self) -> str:
@@ -399,7 +461,6 @@ class GremlinScenarioParallelNode(GremlinScenarioNode):
         **kwargs: dict,
     ):
         super().__init__(*args, **kwargs)
-        raise NotImplementedError("Parallel Scenario Nodes NOT IMPLEMENTED")
 
     def api_model(self) -> dict:
         model: dict = super().api_model()
@@ -414,6 +475,55 @@ class GremlinScenarioParallelNode(GremlinScenarioNode):
         return repr(self)
 
 
+class GremlinScenarioContinuousStatusCheckNode(GremlinScenarioParallelNode):
+    def __init__(
+        self,
+        *args: tuple,
+        **kwargs: dict,
+    ):
+        if not kwargs.get("name", None):
+            kwargs["name"] = "status-check"  # type: ignore
+        super().__init__(*args, **kwargs)
+        self.node_type: str = "ContinuousStatusCheck"  # TODO: validate
+        self._description: str = str()
+        self._endpoint_url: str = str()
+        self._endpoint_headers: dict = {}
+        self._evaluation_ok_status_codes: list = list()
+        self._evaluation_ok_latency_max: int = int()
+        self._evaluation_response_body_evaluation: str = ""
+        self.description: str = kwargs.get("description", None)  # type: ignore
+        self.endpoint_url: str = kwargs.get("endpoint_url", None)  # type: ignore
+        self.endpoint_headers: dict = kwargs.get("endpoint_headers", None)  # type: ignore
+        self.evaluation_ok_status_codes: list = kwargs.get(
+            "evaluation_ok_status_codes", ["200-203"]
+        )  # type: ignore
+        self.evaluation_ok_latency_max: int = kwargs.get("evaluation_ok_latency_max", 500)  # type: ignore
+        self.evaluation_response_body_evaluation: str = kwargs.get(
+            "evaluation_response_body_evaluation", ""
+        )  # type: ignore
+
+    def api_model(self) -> dict:
+        model: dict = {"nodes": {"0": super().api_model()}}
+        model["nodes"]["0"]["endpointConfiguration"] = {
+            "url": self.endpoint_url,
+            "headers": self.endpoint_headers,
+        }
+        model["nodes"]["0"]["evaluationConfiguration"] = {
+            "okStatusCodes": self.evaluation_ok_status_codes,
+            "okLatencyMaxMs": self.evaluation_ok_latency_max,
+            "responseBodyEvaluation": self.evaluation_response_body_evaluation,
+        }
+        model["nodes"]["0"]["statusCheckId"] = ""
+        model["nodes"]["0"]["referenceStatusCheckId"] = ""
+        model["nodes"]["0"]["description"] = self.description
+        model["nodes"]["0"]["thirdPartyPresets"] = "PythonSDK"
+        model["nodes"]["0"]["id"] = "0"  # all parallel nodes have an ID of 0
+        model["nodes"]["0"].pop(
+            "next"
+        )  # verify removal of "next" from parappel nodes, need branchId
+        return model
+
+
 class GremlinScenarioAttackNode(GremlinScenarioSerialNode):
     def __init__(
         self,
@@ -791,6 +901,7 @@ class _GremlinNodeGraph(object):
 
     def get_nodes_linear(
         self,
+        branch_id: int = 0,
         node: GremlinScenarioNode = None,
         parent_id: str = None,
         next_index: int = 0,
@@ -811,26 +922,29 @@ class _GremlinNodeGraph(object):
         next_index : int optional
             The next index to use
         """
+        if not self.head:
+            return {}
         if not node:
-            return self.get_nodes_linear(self.head)
+            return self.get_nodes_linear(branch_id=branch_id, node=self.head)
         self._validate_type(node)
         node.index = str(next_index)
         node.next = str(next_index + 1)
         nodes: dict = {str(next_index): node.data}
-        print(node.id)
+        if branch_id > 0:
+            nodes[str(next_index)]["branchId"] = "concurrentNode-%d" % branch_id
         for node_id in node._edges:
             if node_id == parent_id:
                 continue
             nodes.update(
                 self.get_nodes_linear(
-                    node._edges[node_id]["node"], node.id, next_index + 1
+                    branch_id=branch_id,
+                    node=node._edges[node_id]["node"],
+                    parent_id=node.id,
+                    next_index=next_index + 1,
                 )
             )
         return nodes
 
-    def get_nodes_parallel(self):
-        raise NotImplementedError("Parallel Scenario Nodes NOT IMPLEMENTED")
-
     def insert_between(
         self,
         node: GremlinScenarioNode,
