@@ -6,6 +6,7 @@ import json
 import logging
 import uuid
 
+from gremlinapi.util import deprecated
 from gremlinapi.exceptions import (
     GremlinCommandTargetError,
     GremlinIdentifierError,
@@ -24,6 +25,9 @@ log = logging.getLogger("GremlinAPI.client")
 
 
 class GremlinScenarioHelper(object):
+    @deprecated(
+        "GremlinScenarioHelper class is deprecated, plesae use GremlinScenarioGraphHelper instead"
+    )
     def __init__(
         self,
         *args: tuple,
@@ -37,6 +41,9 @@ class GremlinScenarioHelper(object):
         self.hypothesis: str = kwargs.get("hypothesis", self._hypothesis)  # type: ignore
         self.name: str = kwargs.get("name", self._name)  # type: ignore
 
+    @deprecated(
+        "GremlinScenarioHelper class is deprecated, plesae use GremlinScenarioGraphHelper instead"
+    )
     def add_step(self, _step: "GremlinScenarioStep") -> None:
         if not issubclass(type(_step), GremlinScenarioStep):
             error_msg: str = f"The step must extend from {type(GremlinScenarioStep)}"
@@ -118,6 +125,9 @@ class GremlinScenarioHelper(object):
         log.warning(error_msg)
         raise NotImplementedError(error_msg)
 
+    @deprecated(
+        "GremlinScenarioHelper class is deprecated, plesae use GremlinScenarioGraphHelper instead"
+    )
     def __repr__(self) -> str:
         model: dict = {
             "description": self.description,
@@ -129,6 +139,9 @@ class GremlinScenarioHelper(object):
 
 
 class GremlinScenarioStep(object):
+    @deprecated(
+        "GremlinScenarioStep class is deprecated, plesae use GremlinScenarioGraphHelper instead"
+    )
     def __init__(
         self,
         *args: tuple,
@@ -150,12 +163,18 @@ class GremlinScenarioStep(object):
             log.error(error_msg)
             raise GremlinParameterError(error_msg)
 
+    @deprecated(
+        "GremlinScenarioStep class is deprecated, plesae use GremlinScenarioGraphHelper instead"
+    )
     def __repr__(self) -> str:
         model: dict = {"delay": self.delay}
         return json.dumps(model)
 
 
 class GremlinILFIStep(GremlinScenarioStep):
+    @deprecated(
+        "GremlinILFIStep class is deprecated, plesae use GremlinScenarioGraphHelper instead"
+    )
     def __init__(
         self,
         *args: tuple,
@@ -193,6 +212,9 @@ class GremlinILFIStep(GremlinScenarioStep):
             log.error(error_msg)
             raise GremlinParameterError(error_msg)
 
+    @deprecated(
+        "GremlinILFIStep class is deprecated, plesae use GremlinScenarioGraphHelper instead"
+    )
     def __repr__(self) -> str:
         model: dict = json.loads(super().__repr__())
         model["attacks"] = [
@@ -207,6 +229,9 @@ class GremlinILFIStep(GremlinScenarioStep):
 
 
 class GremlinALFIStep(GremlinScenarioStep):
+    @deprecated(
+        "GremlinALFIStep class is deprecated, plesae use GremlinScenarioGraphHelper instead"
+    )
     def __init__(
         self,
         *args: tuple,
@@ -217,6 +242,9 @@ class GremlinALFIStep(GremlinScenarioStep):
         log.error(error_msg)
         raise NotImplementedError(error_msg)
 
+    @deprecated(
+        "GremlinALFIStep class is deprecated, plesae use GremlinScenarioGraphHelper instead"
+    )
     def __repr__(self) -> str:
         model: dict = json.loads(super().__repr__())
         return json.dumps(model)
